@@ -31,8 +31,13 @@ def ydtk(yd_tk_doc_url):
     print("![](%s)" % ydtk.get_last_img_url(), end="")
 
 def main():
-    func_name = sys.argv[1]
-    args = sys.argv[2:]
+    if len(sys.argv) > 1:
+        func_name = sys.argv[1]
+        args = sys.argv[2:]
+    else:
+        func_name = "ydtk"
+        args = ("https://note.youdao.com/noteshare?id=4f855482811f21fa7e1581222cfda6e7&sub=92AF141CE48343B9A035D46A55A0944A", )
+
     globals()[func_name](*args)
 
 if __name__ == '__main__':
