@@ -15,3 +15,7 @@ def get_url_param_dict(url):
     return params_dict
 
 
+def get_post_data_dict(data):
+    params = parse.parse_qsl(data, 1)
+    params_dict = dict(params)
+    return params_dict
